#ifndef FACEBOOKAUTHDIALOG_H
#define FACEBOOKAUTHDIALOG_H

#include "abstractdialog.h"

class WebView;
class QProgressBar;
class QGridLayout;
class QUrl;

class FacebookAuthDialog : public AbstractDialog
{
    Q_OBJECT
public:
    explicit FacebookAuthDialog(QWidget *parent = 0);

private:
    inline void setLandscapeLayout() { this->setFixedHeight(340); }
    inline void setPortraitLayout() { this->setFixedHeight(600); }

private slots:
    void checkUrlForToken(const QUrl &url);
        
private:
    WebView *m_webView;
    QProgressBar *m_progressBar;
    QGridLayout *m_grid;
};

#endif // FACEBOOKAUTHDIALOG_H
